Name

Struct Name 

pub struct Name(/* private fields */);

Implementations

Source

impl Name

pub fn new(s: &[u8], kind: Option<Oid<'_>>) -> Result<Self, Error>

parse the specified bytes as a gssapi name, with optional kind e.g. GSS_NT_HOSTBASED_SERVICE or GSS_NT_KRB5_PRINCIPAL.

pub fn canonicalize(&self, mech: Option<Oid<'_>>) -> Result<Self, Error>

canonicalize a name for the specified mechanism (or the default mechanism if not specified). This makes a copy of the name.

pub fn export(&self) -> Result<Buf, Error>

Produce a contiguous string representation of a canonicalized name suitable for direct comparison. You must either use a canonical name, or call canonicalize before using this method.

pub fn display_name(&self) -> Result<Buf, Error>

Return the raw textual representation of the internal GSS name. Usually this will be utf8, or at least ascii, but that isn’t guaranteed.

pub fn duplicate(&self) -> Result<Self, Error>

Duplicate the name.