Module util
libgssapi
0.11.0
Module util
Module Items
Structs
In crate libgssapi
libgssapi
Module
util
Structs

Buf
This represents an owned buffer we got from gssapi, it will be deallocated via the library routine when it is dropped.
GssBytes